## system-config-printer

## Copyright (C) 2006, 2007, 2008, 2014 Red Hat, Inc.
## Copyright (C) 2006, 2007 Florian Festi <ffesti@redhat.com>
## Copyright (C) 2006, 2007, 2008 Tim Waugh <twaugh@redhat.com>

## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.

## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.

## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

prefix="/usr/local"
datadir="/usr/local/share"
localedir="/usr/local/share/locale"
pkgdatadir="/usr/local/share/system-config-printer"
VERSION="1.4.6"
PACKAGE="system-config-printer"
DOWNLOADABLE_ONLYPPD=True
DOWNLOADABLE_ONLYFREE=True
DOWNLOADABLE_PKG_ONLYSIGNED=True
